==> foundation-2.7.1.tgz: package/Ticket/Ticket.esm.js <==
import _extends from "@babel/runtime/helpers/extends";
import * as React from 'react';
import { EmotionIconBase } from '@emotion-icons/emotion-icon';
export var Ticket = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var attrs = {
    "fill": "currentColor",
    "xmlns": "http://www.w3.org/2000/svg"
  };
  return /*#__PURE__*/React.createElement(EmotionIconBase, _extends({
    iconAttrs: attrs,
    iconVerticalAlign: "middle",
    iconViewBox: "0 0 100 100"
  }, props, {
    ref: ref
  }), /*#__PURE__*/React.createElement("path", {
    d: "M99.483 33.642c-.029-.029-.063-.05-.094-.077L87.158 21.327a6.12 6.12 0 01-7.722-.763 6.12 6.12 0 01-.761-7.725L66.358.516a1.766 1.766 0 00-2.494 0L.52 63.862l-.003.003a1.763 1.763 0 000 2.494l.001.001 12.325 12.313a6.12 6.12 0 018.489 8.481l12.166 12.154c.046.06.089.122.144.176a1.762 1.762 0 002.493 0l.001.001 63.347-63.349a1.763 1.763 0 000-2.494zm-13.965 2.493L36.136 85.518a1.762 1.762 0 01-2.493 0l-19.159-19.16a1.762 1.762 0 010-2.493l49.381-49.382a1.764 1.764 0 012.493 0l19.16 19.161a1.76 1.76 0 010 2.491z"
  }), /*#__PURE__*/React.createElement("path", {
    d: "M61.923 51.521l-6.821-3.259.83-7.134a.513.513 0 00-.871-.421l-5.097 5.098-6.653-3.178a.512.512 0 00-.683.681l3.179 6.655-5.098 5.096a.515.515 0 00-.099.586.513.513 0 00.52.284l7.132-.829 3.26 6.822a.514.514 0 00.959-.098l1.87-7.476 7.478-1.871a.52.52 0 00.386-.446.514.514 0 00-.292-.51z"
  }));
});
Ticket.displayName = 'Ticket';
export var TicketDimensions = {
  height: 100,
  width: 100
};

==> foundation-10.15.1.tgz: package/Ticket/Ticket.esm.js <==
import _extends from "@babel/runtime/helpers/extends";
import * as React from 'react';
import { StyledIconBase } from '@styled-icons/styled-icon';
export var Ticket = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var attrs = {
    "fill": "currentColor",
    "xmlns": "http://www.w3.org/2000/svg"
  };
  return /*#__PURE__*/React.createElement(StyledIconBase, _extends({
    iconAttrs: attrs,
    iconVerticalAlign: "middle",
    iconViewBox: "0 0 100 100"
  }, props, {
    ref: ref
  }), /*#__PURE__*/React.createElement("path", {
    d: "M99.483 33.642c-.029-.029-.063-.05-.094-.077L87.158 21.327a6.12 6.12 0 01-7.722-.763 6.12 6.12 0 01-.761-7.725L66.358.516a1.766 1.766 0 00-2.494 0L.52 63.862l-.003.003a1.763 1.763 0 000 2.494l.001.001 12.325 12.313a6.12 6.12 0 018.489 8.481l12.166 12.154c.046.06.089.122.144.176a1.762 1.762 0 002.493 0l.001.001 63.347-63.349a1.763 1.763 0 000-2.494zm-13.965 2.493L36.136 85.518a1.762 1.762 0 01-2.493 0l-19.159-19.16a1.762 1.762 0 010-2.493l49.381-49.382a1.764 1.764 0 012.493 0l19.16 19.161a1.76 1.76 0 010 2.491z"
  }), /*#__PURE__*/React.createElement("path", {
    d: "M61.923 51.521l-6.821-3.259.83-7.134a.513.513 0 00-.871-.421l-5.097 5.098-6.653-3.178a.512.512 0 00-.683.681l3.179 6.655-5.098 5.096a.515.515 0 00-.099.586.513.513 0 00.52.284l7.132-.829 3.26 6.822a.514.514 0 00.959-.098l1.87-7.476 7.478-1.871a.52.52 0 00.386-.446.514.514 0 00-.292-.51z"
  }));
});
Ticket.displayName = 'Ticket';
export var TicketDimensions = {
  height: 100,
  width: 100
};
